PATCH: Use !intel_mnemonic instead of SYSV386_COMPAT

H.J. Lu hjl@lucon.org
Fri Jan 4 18:23:00 GMT 2008


I am checking in this to use  !intel_mnemonic instead of
SYSV386_COMPAT.

H.J.
---
2008-01-03  H.J. Lu  <hongjiu.lu@intel.com>

	* config/tc-i386.c (md_assemble): Use !intel_mnemonic instead
	of SYSV386_COMPAT.

--- config/tc-i386.c.intel	2008-01-03 17:05:56.000000000 -0800
+++ config/tc-i386.c	2008-01-03 17:22:08.000000000 -0800
@@ -2205,8 +2205,9 @@ md_assemble (line)
 
   if (intel_syntax)
     {
-      /* Undo SYSV386_COMPAT brokenness when in Intel mode.  See i386.h  */
-      if (SYSV386_COMPAT
+      /* Undo AT&T Mnemonic brokenness when in Intel mode.  See
+	 i386-opc.tbl.  */
+      if (!intel_mnemonic
 	  && (i.tm.base_opcode & 0xfffffde0) == 0xdce0)
 	i.tm.base_opcode ^= Opcode_FloatR;
 



More information about the Binutils mailing list